#!/bin/bash
##############################################################################
# file: gitStatus.sh
#
#                 grep the output of git status . commands and determine 
#                 whether we need to commit any files or if we need to 
#                 track untracked files in an array of project directories.
#                 The project directories may be associated with one or more
#                 git repositories.
#
# author: 			  John Schwartzman, Forte Systems, Inc.
#
# last revision:	01/28/2019
##############################################################################

set -o nounset			# use strict (no unset variables)

escRed='\e[0;31m'       # define a few color escape sequences
escYellow='\e[1;33m'
escGreen='\e[0;32m'
escReset='\e[0m'

# define cmd1 and cmd2
cmd1="git status . | grep -c \"modified:\""
cmd2="git status . | grep -c \"Untracked files:\""

# define the output strings
strNoCommit="has no files that need to be committed."
strCommit="file(s) that need to be committed."
strNoUntracked="has no untracked files."
strUntracked="has one or more untracked files."

# declare an array of the project names and their associated directories
declare -a proj
proj[0]="utility|$HOME/Development/UDS/utility/src"
proj[1]="transport|$HOME/Development/UDS/transport/src"
proj[2]="serverTest|$HOME/Development/UDS/serverTest/src"
proj[3]="clientTest|$HOME/Development/UDS/clientTest/src" 
proj[4]="simpleClientTest|$HOME/Development/UDS/simpleClientTest/src"
proj[5]="throttledServerTest|$HOME/Development/UDS/throttledServerTest/src"
proj[6]="utilityTest|$HOME/Development/UDS/utilityTest/src"
proj[7]="command-history|$HOME/Development/command-history"
proj[8]="git-status|$HOME/Development/git-status"
proj[9]="findit|$HOME/Development/findit"

numProjects=${#proj[@]} # keep track of the number of projects in the array

echo $(date)    # timestamp the output
echo

##############################################################################

# for each project in turn,
#   cd to the project directory
#   evaluate cmd1 and cmd2 and save the count of strings found in
#   count1 and count2
#   output the results to the user based on the contents of count1 and count2

for (( i=0; $i < $numProjects; i++ )); do

    project="${proj[$i]%%|*}"   # get the project name from proj[i]
    dir="${proj[$i]#*|}"        # get the directory name from proj[i]

    cd "${dir}"                 # cd into the repository directory
    
    count1=$(eval ${cmd1})      # execute cmd1 and save the result in count1
    count2=$(eval ${cmd2})      # execute cmd2 and save the result in count2

    if [ $count1 -eq 0 ]
    then
        # there are no strings that need to be committed
        echo -e "${escGreen}${project} $strNoCommit"
    else
        # there are count1 string(s) that need to be committed
        echo -e "${escRed}${project} has $count1 $strCommit"
    fi

    if [ $count2 -ne 0 ]
    then
        # there are one or more untracked files
        echo -e "${escYellow}${project} $strUntracked"
    else
        # there are no untracked files
        echo -e "${escGreen}${project} ${strNoUntracked}"
    fi

    echo -e ${escReset}
done

##############################################################################
